/*$Id$*/
package saccubus;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStream;
import java.util.HashMap;
import java.util.Map;
import java.util.Properties;
import javax.swing.JFrame;
import mockit.Mock;
import mockit.MockClass;
import mockit.Mockit;
import mockit.integration.junit4.JMockit;
import static org.fest.assertions.Assertions.*;
import org.fest.reflect.core.Reflection;
import org.fest.swing.fixture.JFileChooserFixture;
import org.fest.swing.keystroke.KeyStrokeMappingProvider;
import static org.fest.swing.launcher.ApplicationLauncher.application;
import org.fest.swing.core.BasicRobot;
import org.fest.swing.core.Robot;
import org.fest.swing.finder.JFileChooserFinder;
import org.fest.swing.finder.WindowFinder;
import org.fest.swing.fixture.FrameFixture;
import org.fest.swing.keystroke.KeyStrokeMap;
import org.fest.swing.keystroke.KeyStrokeMappingsParser;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import saccubus.properties.SProperties;
import static org.junit.Assert.*;

/**
 *
 * @author yuki
 */
@RunWith(JMockit.class)
public class SaccubusTest {

    private static Robot robot;
    private static FrameFixture window;

    @Before
    public void setUp() throws IOException {
        KeyStrokeMappingsParser parser = new KeyStrokeMappingsParser();
        KeyStrokeMappingProvider provider = parser.parse("fest-swing_mapping.txt");
        KeyStrokeMap.addKeyStrokesFrom(provider);

        robot = BasicRobot.robotWithNewAwtHierarchy();
        application(saccubus.Saccubus.class).start();
        window = WindowFinder.findFrame(JFrame.class).using(robot);
    }

    @After
    public void tearDown() {
        robot.cleanUp();
    }

    private SProperties getProperties() {
        return Reflection.method("getSetting").withReturnType(SProperties.class).in(window.component()).invoke();
    }

    @Test
    public void testConfigSave() throws Exception {
        Mockit.setUpMocks(new MockProperties(), new MockFileOutputStream());

        SProperties.saveSetting(getProperties());
    }

    @Test
    public void testMailAddress() {
        Mockit.setUpMocks(new MockProperties(), new MockFileOutputStream());

        window.tabbedPane("mainTabbedPane").selectTab("基本設定");
        window.textBox("mailAddressField").enterText("mail@example.com");
        SProperties.saveSetting(getProperties());
    }

    @Test
    public void testPassword() {
        Mockit.setUpMocks(new MockProperties(), new MockFileOutputStream());

        window.tabbedPane("mainTabbedPane").selectTab("基本設定");
        window.textBox("passwordField").enterText("pass word input");
        SProperties.saveSetting(getProperties());
    }

    @Test
    public void testUseProxy() {
        Mockit.setUpMocks(new MockProperties(), new MockFileOutputStream());

        window.tabbedPane("mainTabbedPane").selectTab("基本設定");
        window.checkBox("useProxyCheckBox").check();
        SProperties.saveSetting(getProperties());

        window.tabbedPane("mainTabbedPane").selectTab("基本設定");
        window.checkBox("useProxyCheckBox").uncheck();
        SProperties.saveSetting(getProperties());
    }

    @Test
    public void testProxyHost() {
        Mockit.setUpMocks(new MockProperties(), new MockFileOutputStream());

        window.tabbedPane("mainTabbedPane").selectTab("基本設定");
        window.textBox("proxyTextField").enterText("proxy.example.com");
        SProperties.saveSetting(getProperties());
    }

    @Test
    public void testProxyPort() {
        Mockit.setUpMocks(new MockProperties(), new MockFileOutputStream());

        window.tabbedPane("mainTabbedPane").selectTab("基本設定");
        window.textBox("proxyPortTextField").enterText("8090");
        SProperties.saveSetting(getProperties());
    }

    @Test
    public void testMovieSouce() {
        Mockit.setUpMocks(new MockProperties(), new MockFileOutputStream());

        window.tabbedPane("mainTabbedPane").selectTab("保存設定");
        window.tabbedPane("saveTabbedPane").selectTab("入力動画");
        window.radioButton("videoUseNiBrButton").check();
        window.textBox("nibrFileField").enterText("nibr_file.mp4");
        window.radioButton("videoNoSaveButton").check();
        window.checkBox("delVideoCheckBox").click();
        window.textBox("videoSavedFolderField").selectAll().enterText("C:\\works\\");
        window.textBox("videoSavedFileField").selectAll().enterText("C:\\movie_file.flv");
        SProperties.saveSetting(getProperties());

        window.tabbedPane("mainTabbedPane").selectTab("保存設定");
        window.tabbedPane("saveTabbedPane").selectTab("入力動画");
        window.radioButton("videoSaveButton").check();
        window.checkBox("delVideoCheckBox").click();
        window.textBox("videoSavedFolderField").selectAll().enterText("C:\\works\\movie");
        window.textBox("videoSavedFileField").selectAll().enterText("C:\\movie_file\\file.flv");
        SProperties.saveSetting(getProperties());

        window.tabbedPane("mainTabbedPane").selectTab("保存設定");
        window.tabbedPane("saveTabbedPane").selectTab("入力動画");
        window.checkBox("delVideoCheckBox").click();
        window.textBox("videoSavedFolderField").deleteText();
        window.textBox("videoSavedFileField").deleteText();
        window.radioButton("videoUseNiBrButton").check();
        SProperties.saveSetting(getProperties());
    }

    @Test
    public void testMovieSouce2() {
        Mockit.setUpMocks(new MockProperties(), new MockFileOutputStream());

        window.tabbedPane("mainTabbedPane").selectTab("保存設定");
        window.tabbedPane("saveTabbedPane").selectTab("入力動画");
        window.radioButton("saveFolderRadioButton").check();
        window.textBox("videoSavedFolderField").selectAll().enterText("folder\\");
        window.textBox("videoSavedFileField").selectAll().enterText("file.flv");
        SProperties.saveSetting(getProperties());

        window.tabbedPane("mainTabbedPane").selectTab("保存設定");
        window.tabbedPane("saveTabbedPane").selectTab("入力動画");
        window.radioButton("saveFileRadioButton").check();
        window.textBox("videoSavedFolderField").selectAll().enterText("folder1\\folder2\\");
        window.textBox("videoSavedFileField").selectAll().enterText("folder\\file.flv");
        SProperties.saveSetting(getProperties());
    }

    @Test
    public void testMovieSourceFolderButton() {
        Mockit.setUpMocks(new MockProperties(), new MockFileOutputStream());

        window.tabbedPane("mainTabbedPane").selectTab("保存設定");
        window.tabbedPane("saveTabbedPane").selectTab("入力動画");
        window.button("showSavingVideoFolderDialogButton").click();
        JFileChooserFixture chooser = JFileChooserFinder.findFileChooser().using(robot);
        File folder = new File("F:\\docs\\NetBeansProjects");
        chooser.selectFile(folder).approve();
        assertThat(folder.getAbsolutePath()).isEqualTo(window.textBox("videoSavedFolderField").text());
    }

    @Test
    public void testMovieSourceFileButton() {
        Mockit.setUpMocks(new MockProperties(), new MockFileOutputStream());

        window.tabbedPane("mainTabbedPane").selectTab("保存設定");
        window.tabbedPane("saveTabbedPane").selectTab("入力動画");
        window.button("showSavingVideoFileDialogButton").click();
        JFileChooserFixture chooser = JFileChooserFinder.findFileChooser().using(robot);
        File folder = new File("F:\\docs\\NetBeansProjects\\saccubus_frontend\\out\\movie\\aa.flv");
        chooser.selectFile(folder).approve();
        assertThat(folder.getAbsolutePath()).isEqualTo(window.textBox("videoSavedFileField").text());
    }

    @Test
    public void testDownloadComment() {
        Mockit.setUpMocks(new MockProperties(), new MockFileOutputStream());

        window.tabbedPane("mainTabbedPane").selectTab("保存設定");
        window.tabbedPane("saveTabbedPane").selectTab("入力コメント");
        window.checkBox("savingCommentCheckBox").check();
        SProperties.saveSetting(getProperties());

        window.tabbedPane("mainTabbedPane").selectTab("保存設定");
        window.tabbedPane("saveTabbedPane").selectTab("入力コメント");
        window.checkBox("savingCommentCheckBox").uncheck();
        SProperties.saveSetting(getProperties());
    }

    @Test
    public void testDeleteComment() {
        Mockit.setUpMocks(new MockProperties(), new MockFileOutputStream());

        window.tabbedPane("mainTabbedPane").selectTab("保存設定");
        window.tabbedPane("saveTabbedPane").selectTab("入力コメント");
        window.checkBox("delCommentCheckBox").check();
        SProperties.saveSetting(getProperties());

        window.tabbedPane("mainTabbedPane").selectTab("保存設定");
        window.tabbedPane("saveTabbedPane").selectTab("入力コメント");
        window.checkBox("delCommentCheckBox").uncheck();
        SProperties.saveSetting(getProperties());
    }

    @Test
    public void testCommentDownloadNum() {
        Mockit.setUpMocks(new MockProperties(), new MockFileOutputStream());

        window.tabbedPane("mainTabbedPane").selectTab("保存設定");
        window.tabbedPane("saveTabbedPane").selectTab("入力コメント");
        window.checkBox("fixCommentNumCheckBox").check();
        window.textBox("commentNumField").selectAll().enterText("100");
        SProperties.saveSetting(getProperties());

        window.tabbedPane("mainTabbedPane").selectTab("保存設定");
        window.tabbedPane("saveTabbedPane").selectTab("入力コメント");
        window.checkBox("fixCommentNumCheckBox").uncheck();
        window.radioButton("commentSaveFolderRadioButton").check();
        window.textBox("commentNumField").deleteText();
        SProperties.saveSetting(getProperties());

    }

    @Test
    public void testCommentDownloadFolder() {
        Mockit.setUpMocks(new MockProperties(), new MockFileOutputStream());

        window.tabbedPane("mainTabbedPane").selectTab("保存設定");
        window.tabbedPane("saveTabbedPane").selectTab("入力コメント");
        window.radioButton("commentSaveFolderRadioButton").check();
        window.textBox("commentSavedFolderField").selectAll().enterText("c:\\comment\\");
        window.textBox("commentSavedFileField").selectAll().enterText("c:\\comment\\file.xml");
        SProperties.saveSetting(getProperties());

        window.tabbedPane("mainTabbedPane").selectTab("保存設定");
        window.tabbedPane("saveTabbedPane").selectTab("入力コメント");
        window.radioButton("commentSaveFileRadioButton").check();
        window.textBox("commentSavedFolderField").selectAll().enterText("comment");
        window.textBox("commentSavedFileField").selectAll().enterText("file.xml");
        SProperties.saveSetting(getProperties());

    }

    @Test
    public void testCommentFolderButton() {
        Mockit.setUpMocks(new MockProperties(), new MockFileOutputStream());

        window.tabbedPane("mainTabbedPane").selectTab("保存設定");
        window.tabbedPane("saveTabbedPane").selectTab("入力コメント");
        window.button("showSavingCommentFolderDialogButton").click();
        JFileChooserFixture chooser = JFileChooserFinder.findFileChooser().using(robot);
        File folder = new File("F:\\docs\\NetBeansProjects");
        chooser.selectFile(folder).approve();
        assertThat(folder.getAbsolutePath()).isEqualTo(window.textBox("commentSavedFolderField").text());
    }

    @Test
    public void testCommentFileButton() {
        Mockit.setUpMocks(new MockProperties(), new MockFileOutputStream());

        window.tabbedPane("mainTabbedPane").selectTab("保存設定");
        window.tabbedPane("saveTabbedPane").selectTab("入力コメント");
        window.button("showSavingCommentFileDialogButton").click();
        JFileChooserFixture chooser = JFileChooserFinder.findFileChooser().using(robot);
        File folder = new File("F:\\docs\\NetBeansProjects\\comment.xml");
        chooser.selectFile(folder).approve();
        assertThat(folder.getAbsolutePath()).isEqualTo(window.textBox("commentSavedFileField").text());
    }

    @Test
    public void testDownloadTcomment() {
        Mockit.setUpMocks(new MockProperties(), new MockFileOutputStream());

        window.tabbedPane("mainTabbedPane").selectTab("保存設定");
        window.tabbedPane("saveTabbedPane").selectTab("入力投稿者コメント");
        window.checkBox("needDownloadTcomment").check();
        SProperties.saveSetting(getProperties());

        window.tabbedPane("mainTabbedPane").selectTab("保存設定");
        window.tabbedPane("saveTabbedPane").selectTab("入力投稿者コメント");
        window.checkBox("needDownloadTcomment").uncheck();
        SProperties.saveSetting(getProperties());
    }

    @Test
    public void testDeleteTcomment() {
        Mockit.setUpMocks(new MockProperties(), new MockFileOutputStream());

        window.tabbedPane("mainTabbedPane").selectTab("保存設定");
        window.tabbedPane("saveTabbedPane").selectTab("入力投稿者コメント");
        window.checkBox("delTcomment").check();
        SProperties.saveSetting(getProperties());

        window.tabbedPane("mainTabbedPane").selectTab("保存設定");
        window.tabbedPane("saveTabbedPane").selectTab("入力投稿者コメント");
        window.checkBox("delTcomment").uncheck();
        SProperties.saveSetting(getProperties());
    }

    @Test
    public void testTcommentDownloadFolder() {
        Mockit.setUpMocks(new MockProperties(), new MockFileOutputStream());

        window.tabbedPane("mainTabbedPane").selectTab("保存設定");
        window.tabbedPane("saveTabbedPane").selectTab("入力投稿者コメント");
        window.radioButton("tcommentSaveInFolder").check();
        window.textBox("tcommentFolder").selectAll().enterText("c:\\comment\\");
        window.textBox("tcommentFile").selectAll().enterText("c:\\comment\\file.xml");
        SProperties.saveSetting(getProperties());

        window.tabbedPane("mainTabbedPane").selectTab("保存設定");
        window.tabbedPane("saveTabbedPane").selectTab("入力投稿者コメント");
        window.radioButton("tcommentSaveToFile").check();
        window.textBox("tcommentFolder").selectAll().enterText("comment");
        window.textBox("tcommentFile").selectAll().enterText("file.xml");
        SProperties.saveSetting(getProperties());

    }

    @Test
    public void testTcommentFolderButton() {
        Mockit.setUpMocks(new MockProperties(), new MockFileOutputStream());

        window.tabbedPane("mainTabbedPane").selectTab("保存設定");
        window.tabbedPane("saveTabbedPane").selectTab("入力投稿者コメント");
        window.button("tcoomentFolderChooserButton").click();
        JFileChooserFixture chooser = JFileChooserFinder.findFileChooser().using(robot);
        File folder = new File("F:\\docs\\NetBeansProjects\\saccubus_frontend\\src");
        chooser.selectFile(folder).approve();
        assertThat(folder.getAbsolutePath()).isEqualTo(window.textBox("tcommentFolder").text());
    }

    @Test
    public void testTcommentFileButton() {
        Mockit.setUpMocks(new MockProperties(), new MockFileOutputStream());

        window.tabbedPane("mainTabbedPane").selectTab("保存設定");
        window.tabbedPane("saveTabbedPane").selectTab("入力投稿者コメント");
        window.button("tcommentFileChooserButton").click();
        JFileChooserFixture chooser = JFileChooserFinder.findFileChooser().using(robot);
        File folder = new File("F:\\docs\\NetBeansProjects\\tcomment.xml");
        chooser.selectFile(folder).approve();
        assertThat(folder.getAbsolutePath()).isEqualTo(window.textBox("tcommentFile").text());
    }

    @Test
    public void testConvertVideo() {
        Mockit.setUpMocks(new MockProperties(), new MockFileOutputStream());

        window.tabbedPane("mainTabbedPane").selectTab("保存設定");
        window.tabbedPane("saveTabbedPane").selectTab("出力コメント付き動画");
        window.checkBox("savingConvertedVideoCheckBox").uncheck();
        SProperties.saveSetting(getProperties());

        window.tabbedPane("mainTabbedPane").selectTab("保存設定");
        window.tabbedPane("saveTabbedPane").selectTab("出力コメント付き動画");
        window.checkBox("savingConvertedVideoCheckBox").check();
        SProperties.saveSetting(getProperties());
    }

    @Test
    public void testAddComment() {
        Mockit.setUpMocks(new MockProperties(), new MockFileOutputStream());

        window.tabbedPane("mainTabbedPane").selectTab("保存設定");
        window.tabbedPane("saveTabbedPane").selectTab("出力コメント付き動画");
        window.checkBox("addComment").uncheck();
        SProperties.saveSetting(getProperties());

        window.tabbedPane("mainTabbedPane").selectTab("保存設定");
        window.tabbedPane("saveTabbedPane").selectTab("出力コメント付き動画");
        window.checkBox("addComment").check();
        SProperties.saveSetting(getProperties());
    }

    @Test
    public void testAddTcomment() {
        Mockit.setUpMocks(new MockProperties(), new MockFileOutputStream());

        window.tabbedPane("mainTabbedPane").selectTab("保存設定");
        window.tabbedPane("saveTabbedPane").selectTab("出力コメント付き動画");
        window.checkBox("addTcomment").uncheck();
        SProperties.saveSetting(getProperties());

        window.tabbedPane("mainTabbedPane").selectTab("保存設定");
        window.tabbedPane("saveTabbedPane").selectTab("出力コメント付き動画");
        window.checkBox("addTcomment").check();
        SProperties.saveSetting(getProperties());
    }

    @Test
    public void testNoAddId() {
        Mockit.setUpMocks(new MockProperties(), new MockFileOutputStream());

        window.tabbedPane("mainTabbedPane").selectTab("保存設定");
        window.tabbedPane("saveTabbedPane").selectTab("出力コメント付き動画");
        window.checkBox("notAddVideoIdConvVideoCheckBox").uncheck();
        SProperties.saveSetting(getProperties());

        window.tabbedPane("mainTabbedPane").selectTab("保存設定");
        window.tabbedPane("saveTabbedPane").selectTab("出力コメント付き動画");
        window.checkBox("notAddVideoIdConvVideoCheckBox").check();
        SProperties.saveSetting(getProperties());
    }

    @Test
    public void testConvertedVideoSavePlace() {
        Mockit.setUpMocks(new MockProperties(), new MockFileOutputStream());

        window.tabbedPane("mainTabbedPane").selectTab("保存設定");
        window.tabbedPane("saveTabbedPane").selectTab("出力コメント付き動画");
        window.radioButton("convSaveFolderRadioButton").check();
        window.textBox("convertedVideoSavedFolderField").setText("folder");
        window.textBox("convertedVideoSavedFileField").setText("converted.avi");
        SProperties.saveSetting(getProperties());

        window.tabbedPane("mainTabbedPane").selectTab("保存設定");
        window.tabbedPane("saveTabbedPane").selectTab("出力コメント付き動画");
        window.radioButton("convSaveFileRadioButton").check();
        window.textBox("convertedVideoSavedFolderField").setText("folder\\folder2");
        window.textBox("convertedVideoSavedFileField").setText("folder\\converted.avi");
        SProperties.saveSetting(getProperties());
    }

    @MockClass(realClass = FileOutputStream.class)
    public static class MockFileOutputStream {

        public MockFileOutputStream() {
        }

        @Mock
        public MockFileOutputStream(String name) {
            System.out.println("FileOutputStream constructor mocked.");
        }
    }

    @MockClass(realClass = Properties.class)
    public static class MockProperties {

        private Map<String, String> map = new HashMap<String, String>();

        @Mock
        public void storeToXML(OutputStream os, String comment) {
            System.out.println("storeToXML mocked.");

            // 基本設定
            window.tabbedPane("mainTabbedPane").selectTab("基本設定");
            // ユーザ設定
            assertThat(map.get("MailAddress")).isEqualTo(window.textBox("mailAddressField").text());
            assertThat(map.get("Password")).isEqualTo(window.textBox("passwordField").text());
            // プロキシ設定
            assertThat(Boolean.parseBoolean(map.get("UseProxy"))).isEqualTo(window.checkBox("useProxyCheckBox").
                    component().isSelected());
            assertThat(map.get("Proxy")).isEqualTo(window.textBox("proxyTextField").text());
            final String port = window.textBox("proxyPortTextField").text();
            if (!"".equals(port)) {
                assertThat(map.get("ProxyPort")).isEqualTo(port);
            } else {
                assertThat(map.get("ProxyPort")).as("ポートが空の場合には-1(無効な番号)を設定する").isEqualTo("-1");
            }

            // 保存設定 - 入力動画
            window.tabbedPane("mainTabbedPane").selectTab("保存設定");
            window.tabbedPane("saveTabbedPane").selectTab("入力動画");

            final VideoSaveKind saveVideo = VideoSaveKind.valueOf(map.get("SaveVideoFile"));
            switch (saveVideo) {
                case NO_SAVE:
                    window.radioButton("videoNoSaveButton").requireSelected();
                    window.radioButton("videoSaveButton").requireNotSelected();
                    window.radioButton("videoUseNiBrButton").requireNotSelected();
                    break;
                case SAVE:
                    window.radioButton("videoNoSaveButton").requireNotSelected();
                    window.radioButton("videoSaveButton").requireSelected();
                    window.radioButton("videoUseNiBrButton").requireNotSelected();
                    break;
                case NICOBROWSER:
                    window.radioButton("videoNoSaveButton").requireNotSelected();
                    window.radioButton("videoSaveButton").requireNotSelected();
                    window.radioButton("videoUseNiBrButton").requireSelected();
                    break;
                default:
                    fail();
            }

            final boolean videoAutoNaming = Boolean.parseBoolean(map.get("VideoFixFileName"));
            if (videoAutoNaming) {
                window.radioButton("saveFolderRadioButton").requireSelected();
                window.radioButton("saveFileRadioButton").requireNotSelected();
            } else {
                window.radioButton("saveFolderRadioButton").requireNotSelected();
                window.radioButton("saveFileRadioButton").requireSelected();
            }

            assertThat(Boolean.parseBoolean(map.get("DeleteVideoAfterConv"))).isEqualTo(window.checkBox(
                    "delVideoCheckBox").component().isSelected());
            assertThat(map.get("VideoFixFileNameFolder")).isEqualTo(new File(window.textBox("videoSavedFolderField").
                    text()).getPath());
            assertThat(map.get("VideoFile")).isEqualTo(window.textBox("videoSavedFileField").text());

            assertThat(map.get("NicoBrowserFileName")).isEqualTo(window.textBox("nibrFileField").text());


            // 保存設定 - 入力コメント
            window.tabbedPane("saveTabbedPane").selectTab("入力コメント");

            assertThat(Boolean.parseBoolean(map.get("SaveCommentFile"))).isEqualTo(window.checkBox(
                    "savingCommentCheckBox").component().isSelected());
            assertThat(Boolean.parseBoolean(map.get("DeleteCommentAfterConv"))).isEqualTo(window.checkBox(
                    "delCommentCheckBox").component().isSelected());
            assertThat(Boolean.parseBoolean(map.get("FixCommentSize"))).isEqualTo(window.checkBox(
                    "fixCommentNumCheckBox").component().isSelected());
            // 空だったらデフォルト値500を設定する
            String backComment = (window.textBox("commentNumField").text().isEmpty()) ? "500" : window.textBox(
                    "commentNumField").text();
            assertThat(map.get("BackComment")).isEqualTo(backComment);

            final boolean commentAutoNaming = Boolean.parseBoolean(map.get("CommentFixFileName"));
            if (commentAutoNaming) {
                window.radioButton("commentSaveFolderRadioButton").requireSelected();
                window.radioButton("commentSaveFileRadioButton").requireNotSelected();
            } else {
                window.radioButton("commentSaveFolderRadioButton").requireNotSelected();
                window.radioButton("commentSaveFileRadioButton").requireSelected();
            }

            assertThat(map.get("CommentFixFileNameFolder")).isEqualTo(new File(window.textBox("commentSavedFolderField").
                    text()).getPath());
            assertThat(map.get("CommentFile")).isEqualTo(window.textBox("commentSavedFileField").text());


            // 保存設定 - 入力投稿者コメント
            window.tabbedPane("saveTabbedPane").selectTab("入力投稿者コメント");

            assertThat(Boolean.parseBoolean(map.get("TCDownload"))).isEqualTo(window.checkBox("needDownloadTcomment").
                    component().isSelected());
            assertThat(Boolean.parseBoolean(map.get("TCDelete"))).isEqualTo(window.checkBox("delTcomment").component().
                    isSelected());

            final boolean tcommAutoNaming = Boolean.parseBoolean(map.get("TCAutoNaming"));
            if (tcommAutoNaming) {
                window.radioButton("tcommentSaveInFolder").requireSelected();
                window.radioButton("tcommentSaveToFile").requireNotSelected();
            } else {
                window.radioButton("tcommentSaveInFolder").requireNotSelected();
                window.radioButton("tcommentSaveToFile").requireSelected();
            }

            assertThat(map.get("TCDirectory")).isEqualTo(window.textBox("tcommentFolder").text());
            assertThat(map.get("TCFileName")).isEqualTo(window.textBox("tcommentFile").text());


            // 保存設定 - 出力コメント付き動画
            window.tabbedPane("saveTabbedPane").selectTab("出力コメント付き動画");

            assertThat(Boolean.parseBoolean(map.get("SaveConvertedFile"))).isEqualTo(window.checkBox(
                    "savingConvertedVideoCheckBox").component().isSelected());
            assertThat(Boolean.parseBoolean(map.get("AddComment"))).isEqualTo(window.checkBox("addComment").component().
                    isSelected());
            assertThat(Boolean.parseBoolean(map.get("AddTcomment"))).isEqualTo(window.checkBox("addTcomment").component().
                    isSelected());

            final boolean convertedAutoNaming = Boolean.parseBoolean(map.get("ConvFixFileName"));
            if (convertedAutoNaming) {
                window.radioButton("convSaveFolderRadioButton").requireSelected();
                window.radioButton("convSaveFileRadioButton").requireNotSelected();
            } else {
                window.radioButton("convSaveFolderRadioButton").requireNotSelected();
                window.radioButton("convSaveFileRadioButton").requireSelected();
            }

            assertThat(Boolean.parseBoolean(map.get("NotAddVideoIDtoConverted"))).isEqualTo(window.checkBox(
                    "notAddVideoIdConvVideoCheckBox").component().isSelected());
            assertThat(map.get("ConvFixFileNameFolder")).isEqualTo(
                    window.textBox("convertedVideoSavedFolderField").text());
            assertThat(map.get("ConvertedFile")).isEqualTo(window.textBox("convertedVideoSavedFileField").text());


            // 基本設定
            window.tabbedPane("mainTabbedPane").selectTab("動画設定");

            assertThat(map.get("FFnpegPath")).isEqualTo(window.textBox("ffmpegPathField").text());
            assertThat(map.get("VhookPath")).isEqualTo(window.textBox("vhookPathField").text());

            assertThat(map.get("CMD_EXT")).isEqualTo(window.textBox("extOptionField").text());
            assertThat(map.get("CMD_MAIN")).isEqualTo(window.textBox("mainOptionField").text());
            assertThat(map.get("CMD_IN")).isEqualTo(window.textBox("inputOptionField").text());
            assertThat(map.get("CMD_OUT")).isEqualTo(window.textBox("outputOptionField").text());


            // 変換設定
            window.tabbedPane("mainTabbedPane").selectTab("変換設定");
            assertThat(Boolean.parseBoolean(map.get("VhookDisabled"))).isEqualTo(window.checkBox("disableVhookCheckBox").
                    component().isSelected());
            assertThat(map.get("ShowCommentNum")).isEqualTo(window.textBox("viewCommentField").text());
            assertThat(map.get("FontPath")).isEqualTo(window.textBox("fontPathField").text());
            assertThat(map.get("FontIndex")).isEqualTo(window.textBox("fontIndexField").text());
            window.comboBox("shadowComboBox").requireSelection(Integer.parseInt(map.get("ShadowIndex")));
            assertThat(Boolean.parseBoolean(map.get("ShowVideo"))).isEqualTo(window.checkBox("showConvVideoCheckBox").
                    component().isSelected());
            assertThat(Boolean.parseBoolean(map.get("FixFontSize"))).isEqualTo(window.checkBox("fixFontSizeCheckBox").
                    component().isSelected());
            assertThat(Boolean.parseBoolean(map.get("OpaqueComment"))).isEqualTo(window.checkBox("opaqueCommentCheckBox").
                    component().isSelected());

            assertThat(map.get("NG_Word")).isEqualTo(window.textBox("ngWordTextField").text());
            assertThat(map.get("NG_ID")).isEqualTo(window.textBox("ngIdTextField").text());


//assertThat(map.get("TempDir")).isEqualTo(window.
        }

        @Mock
        public Object setProperty(String key, String value) {
            String prev = map.put(key, value);
//            assertNull(prev);
            return prev;
        }
    }
}
